==> index_now-1.0.5.tar.gz: index_now/tests/src/Unit/TermOperationsTest.php <==
<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\index_now\TermOperations;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\taxonomy\Entity\Term;
use Drupal\user\Entity\Role;
use Drupal\Tests\UnitTestCase;
use Drupal\user\RoleStorageInterface;
use Prophecy\Argument;

/**
 * Tests the TermOperations class.
 *
 * @coversDefaultClass \Drupal\index_now\TermOperations
 *
 * @group index_now
 */
class TermOperationsTest extends UnitTestCase {

  const CONFIG_NAME = 'index_now.settings';

  const CONFIG_EXCLUDE_NAME = 'exclude_vocabularies';

  const PERMISSION = 'access content';

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->configFactory = $this->prophesize(ConfigFactoryInterface::class);
    $this->entityTypeManager = $this->prophesize(EntityTypeManagerInterface::class);
    $this->indexNow = $this->prophesize(IndexNowInterface::class);

    $this->roleStorage = $this->prophesize(RoleStorageInterface::class);
    $this->entityTypeManager
      ->getStorage('user_role')
      ->willReturn($this->roleStorage->reveal());

    $this->TermOperations = new TermOperations(
      $this->configFactory->reveal(),
      $this->entityTypeManager->reveal(),
      $this->indexNow->reveal()
    );
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsUnpublished() {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(FALSE);

    $this->roleStorage->load(Argument::any())
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->TermOperations->isIndexable($term->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testUserCantAccessContent() {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(FALSE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->TermOperations->isIndexable($term->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testVocabularyIsExcluded() {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $term->bundle()
      ->ShouldBeCalled()
      ->willReturn('foo');

    $this->assertTrue(!$this->TermOperations->isIndexable($term->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testTermIsIndexable() {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $term->bundle()
      ->ShouldBeCalled()
      ->willReturn('bar');

    $this->assertTrue($this->TermOperations->isIndexable($term->reveal()));
  }

}

==> index_now-2.0.0.tar.gz: index_now/tests/src/Unit/TermOperationsTest.php <==
<?php

namespace Drupal\Tests\index_now\Unit;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\index_now\TermOperations;
use Drupal\index_now\Service\IndexNowInterface;
use Drupal\taxonomy\Entity\Term;
use Drupal\user\Entity\Role;
use Drupal\Tests\UnitTestCase;
use Drupal\user\RoleStorageInterface;
use Prophecy\Argument;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Tests the TermOperations class.
 *
 * @coversDefaultClass \Drupal\index_now\TermOperations
 *
 * @group index_now
 */
class TermOperationsTest extends UnitTestCase {

  use ProphecyTrait;

  const CONFIG_NAME = 'index_now.settings';

  const CONFIG_EXCLUDE_NAME = 'exclude_vocabularies';

  const PERMISSION = 'access content';

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->configFactory = $this->prophesize(ConfigFactoryInterface::class);
    $this->entityTypeManager = $this->prophesize(EntityTypeManagerInterface::class);
    $this->indexNow = $this->prophesize(IndexNowInterface::class);

    $this->roleStorage = $this->prophesize(RoleStorageInterface::class);
    $this->entityTypeManager
      ->getStorage('user_role')
      ->willReturn($this->roleStorage->reveal());

    $this->TermOperations = new TermOperations(
      $this->configFactory->reveal(),
      $this->entityTypeManager->reveal(),
      $this->indexNow->reveal()
    );
  }

  /**
   * @covers ::isIndexable
   */
  public function testNodeIsUnpublished(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(FALSE);

    $this->roleStorage->load(Argument::any())
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->TermOperations->isIndexable($term->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testUserCantAccessContent(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(FALSE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldNotBeCalled();

    $this->assertTrue(!$this->TermOperations->isIndexable($term->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testVocabularyIsExcluded(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $term->bundle()
      ->ShouldBeCalled()
      ->willReturn('foo');

    $this->assertTrue(!$this->TermOperations->isIndexable($term->reveal()));
  }

  /**
   * @covers ::isIndexable
   */
  public function testTermIsIndexable(): void {
    $term = $this->prophesize(Term::class);

    $term->isPublished()
      ->willReturn(TRUE);

    $role_prophecy = $this->prophesize(Role::class);
    $role_prophecy->hasPermission(self::PERMISSION)
      ->willReturn(TRUE);
    $this->roleStorage->load(Argument::any())
      ->ShouldBeCalled()
      ->willReturn($role_prophecy->reveal());

    $this->config = $this->prophesize(Config::class);
    $this->config
      ->get(self::CONFIG_EXCLUDE_NAME)
      ->willReturn(['foo']);
    $this->configFactory
      ->getEditable(self::CONFIG_NAME)
      ->ShouldBeCalled()
      ->willReturn($this->config->reveal());

    $term->bundle()
      ->ShouldBeCalled()
      ->willReturn('bar');

    $this->assertTrue($this->TermOperations->isIndexable($term->reveal()));
  }

}
